#!/bin/sh -eu

. install2-init-functions

syslog_conf=$destdir/etc/syslog-ng.conf


[ -z "$AUTOINSTALL" ] || exit 0
[ -f "$syslog_conf" ] || exit 0

cat >"$syslog_conf"<<__EOF__

options { sync (0);
          time_reopen (10);
          log_fifo_size (1000);
          long_hostnames (off);
          use_dns (yes);
          use_fqdn (yes);
          create_dirs (yes);
          keep_hostname (yes);
        };

source sys { unix-dgram ("/dev/log"); file("/proc/kmsg"); internal(); udp(); };

destination kerninfo	{ file("/var/log/\$HOST_FROM/kernel/info"); };
destination kernwarn	{ file("/var/log/\$HOST_FROM/kernel/warnings"); };
destination kernerr	{ file("/var/log/\$HOST_FROM/kernel/errors"); };

destination userinfo	{ file("/var/log/\$HOST_FROM/user/info"); };
destination userwarn	{ file("/var/log/\$HOST_FROM/user/warnings"); };
destination usererr	{ file("/var/log/\$HOST_FROM/user/errors"); };

destination mailinfo	{ file("/var/log/\$HOST_FROM/mail/info"); };
destination mailwarn	{ file("/var/log/\$HOST_FROM/mail/warnings"); };
destination mailerr	{ file("/var/log/\$HOST_FROM/mail/errors"); };
destination mailall	{ file("/var/log/\$HOST_FROM/mail/all"); };

destination auth	{ file("/var/log/\$HOST_FROM/auth/messages"); };
destination authpriv	{ file("/var/log/\$HOST_FROM/auth/secure"); };
destination authall	{ file("/var/log/\$HOST_FROM/auth/all"); };

destination daemoninfo	{ file("/var/log/\$HOST_FROM/daemons/info"); };
destination daemonwarn	{ file("/var/log/\$HOST_FROM/daemons/warnings"); };
destination daemonerr	{ file("/var/log/\$HOST_FROM/daemons/errors"); };

destination lprinfo	{ file("/var/log/\$HOST_FROM/lpr/info"); };
destination lprwarn	{ file("/var/log/\$HOST_FROM/lpr/warnings"); };
destination lprerr	{ file("/var/log/\$HOST_FROM/lpr/error"); };

destination newsinfo	{ file("/var/log/\$HOST_FROM/news/info"); };
destination newswarn	{ file("/var/log/\$HOST_FROM/news/warnings"); };
destination newserr	{ file("/var/log/\$HOST_FROM/news/error"); };

destination uucpinfo	{ file("/var/log/\$HOST_FROM/uucp/info"); };
destination uucpwarn	{ file("/var/log/\$HOST_FROM/uucp/warnings"); };
destination uucperr	{ file("/var/log/\$HOST_FROM/uucp/error"); };

destination croninfo	{ file("/var/log/\$HOST_FROM/cron/info"); };
destination cronwarn	{ file("/var/log/\$HOST_FROM/cron/warnings"); };
destination cronerr	{ file("/var/log/\$HOST_FROM/cron/error"); };

destination ftpinfo	{ file("/var/log/\$HOST_FROM/ftp/info"); };
destination ftpwarn	{ file("/var/log/\$HOST_FROM/ftp/warnings"); };
destination ftperr	{ file("/var/log/\$HOST_FROM/ftp/error"); };

destination mesg	{ file("/var/log/\$HOST_FROM/syslog/messages"); };
destination alert	{ file("/var/log/\$HOST_FROM/syslog/alert"); };
destination emerg	{ file("/var/log/\$HOST_FROM/syslog/emerg"); };
destination spool	{ file("/var/log/\$HOST_FROM/syslog/spooler"); };
destination boot	{ file("/var/log/\$HOST_FROM/syslog/boot"); };
destination consoleall	{ file("/dev/tty12"); };

# Generic filters
filter f_info		{ level(debug,info,notice); };
filter f_warn		{ level(warn); };
filter f_error		{ level(error); };
filter f_emergency	{ level(emerg); };
filter f_alert		{ level(alert); };
filter f_mail		{ facility(mail); };
filter f_cron		{ facility(cron); };
filter f_kernel		{ facility(kern); };
filter f_lpr		{ facility(lpr); };
filter f_news		{ facility(news); };
filter f_daemon		{ facility(daemon); };
filter f_uucp		{ facility(uucp); };
filter f_ftp		{ facility(ftp); };

# Specific filters
filter f_authall	{ facility(auth,authpriv); };
filter f_auth		{ facility(auth); };
filter f_authpriv	{ facility(authpriv); };
filter f_user		{ facility(user); };

# Log anything (except mail) of level info or higher.  Don't log private authentication messages
filter f_mesgs		{ level(info) and not facility(mail,authpriv); };

# authpriv logging (restricted)
filter f_secure		{ facility(authpriv); };
filter f_spool		{ facility(uucp) or (facility(news) and level(crit)); };
filter f_boot		{ facility(local7); };
filter f_syslog		{ not facility(auth, authpriv); };

# Log to logfiles
log { source(sys); filter(f_kernel); filter(f_info); destination(kerninfo); };
log { source(sys); filter(f_kernel); filter(f_warn); destination(kernwarn); };
log { source(sys); filter(f_kernel); filter(f_error); destination(kernerr); };

log { source(sys); filter(f_user); filter(f_info); destination(userinfo); };
log { source(sys); filter(f_user); filter(f_warn); destination(userwarn); };
log { source(sys); filter(f_user); filter(f_error); destination(usererr); };

log { source(sys); filter(f_mail); filter(f_info); destination(mailinfo); };
log { source(sys); filter(f_mail); filter(f_warn); destination(mailwarn); };
log { source(sys); filter(f_mail); filter(f_error); destination(mailerr); };
log { source(sys); filter(f_mail); destination(mailall); };

log { source(sys); filter(f_daemon); filter(f_info); destination(daemoninfo); };
log { source(sys); filter(f_daemon); filter(f_warn); destination(daemonwarn); };
log { source(sys); filter(f_daemon); filter(f_error); destination(daemonerr); };

log { source(sys); filter(f_authall); destination(authall); };
log { source(sys); filter(f_auth); destination(auth); };
log { source(sys); filter(f_authpriv); destination(authpriv); };

log { source(sys); filter(f_lpr); filter(f_info); destination(lprinfo); };
log { source(sys); filter(f_lpr); filter(f_warn); destination(lprwarn); };
log { source(sys); filter(f_lpr); filter(f_error); destination(lprerr); };

log { source(sys); filter(f_news); filter(f_info); destination(newsinfo); };
log { source(sys); filter(f_news); filter(f_warn); destination(newswarn); };
log { source(sys); filter(f_news); filter(f_error); destination(newserr); };

log { source(sys); filter(f_uucp); filter(f_info); destination(uucpinfo); };
log { source(sys); filter(f_uucp); filter(f_warn); destination(uucpwarn); };
log { source(sys); filter(f_uucp); filter(f_error); destination(uucperr); };

log { source(sys); filter(f_cron); filter(f_info); destination(croninfo); };
log { source(sys); filter(f_cron); filter(f_warn); destination(cronwarn); };
log { source(sys); filter(f_cron); filter(f_error); destination(cronerr); };

log { source(sys); filter(f_ftp); filter(f_info); destination(ftpinfo); };
log { source(sys); filter(f_ftp); filter(f_warn); destination(ftpwarn); };
log { source(sys); filter(f_ftp); filter(f_error); destination(ftperr); };

log { source(sys); filter(f_mesgs); destination(mesg); };
log { source(sys); filter(f_alert); destination(alert); };
log { source(sys); filter(f_emergency); destination(emerg); };
log { source(sys); filter(f_spool); destination(spool); };
log { source(sys); filter(f_boot); destination(boot); };
log { source(sys); destination(consoleall); };

__EOF__
